import * as React from 'react';
import classNames from 'classnames';
import './index.less';
const clsPrefix = 'osui-highlight-text';
const breakWordsByMark = (input, mark, props) => {
    const className = props && props.className || '';
    if (typeof input !== 'string' || typeof mark !== 'string') {
        return input;
    }
    const parts = input.split(new RegExp(`(${mark})`, 'gi'));
    return parts.map((part, index) => {
        if (!part) {
            return null;
        }
        if (part.toLowerCase() === mark.toLowerCase()) {
            return (React.createElement("span", { 
                // eslint-disable-next-line react/no-array-index-key
                key: `${part}-${index}`, ...props, className: classNames(`${clsPrefix}-mark`, className) }, part));
        }
        else {
            return part;
        }
    });
};
const HighlightText = ({ children, mark, markProps }) => {
    const [text, setText] = React.useState(children);
    React.useLayoutEffect(() => {
        const requestId = window.requestAnimationFrame(() => {
            setText(breakWordsByMark(children, mark, markProps));
        });
        return () => {
            window.cancelAnimationFrame(requestId);
        };
    }, 
    // eslint-disable-next-line react-hooks/exhaustive-deps
    [children, mark]);
    return React.createElement(React.Fragment, null, text);
};
export default HighlightText;
//# sourceMappingURL=index.js.map